Learn R Programming

oRaklE (version 1.0.2)

add_holidays_mid_term: Add holidays to the mid-term series

Description

This function adds a dummy variable for holidays to the mid-term data series. Information on the holidays is retrieved from "https://date.nager.at/api/v3/publicholidays/".

Usage

add_holidays_mid_term(midterm_data)

Value

The mid-term series with an additional column of holiday dummies.

Arguments

midterm_data

The mid-term data series resulting from the function decompose_load_data.

See Also

See also mid_term_lm for the prediction model.

Examples

Run this code
example_midterm_demand_data <- add_holidays_mid_term(example_decomposed_data$midterm)
head(example_midterm_demand_data)

Run the code above in your browser using DataLab