| example_demand_data_filled | R Documentation |
This dataset contains the same data as example_demand_data with any missing values filled.
example_demand_data_filled
A data frame with 43,824 rows and 7 columns:
dateThe date and time of the demand measurement (in YYYY-MM-DD HH:MM:SS format).
loadThe electricity demand.
unitThe unit of measurement (MW).
yearThe year of the respective timepoint.
time_intervalThe time interval at which the demand was reported (e.g., 60 mins).
countryThe country, represented by the ISO2C country code (e.g., FR for France).
exampleA boolean indicator to mark this dataset as an example dataset.
Transparency Platform of the European Network of Transmission System Operators for Electricity (ENTSO-E, https://transparency.entsoe.eu/)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.