| example_longterm_data | R Documentation |
This dataset contains the average hourly electricity demand per year for France from 2006 until 2021.
It is an extension of the long-term component of example_decomposed_data with historical data from the ENTSO-E Power Stats archive (https://www.entsoe.eu/data/power-stats/).
example_longterm_data
A data frame with 16 rows and 4 columns:
countryThe country, represented by the ISO2C country code (e.g., FR for France).
yearThe year of the observation.
avg_hourly_demandThe average hourly electricity demand (in megawatts) for each year.
exampleA boolean indicator to mark this dataset as an example dataset.
Transparency Platform of the European Network of Transmission System Operators for Electricity (ENTSO-E, https://transparency.entsoe.eu/) ; ENTSO-E Power Stats Archive (https://www.entsoe.eu/data/power-stats/)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.