| example_longterm_future_macro_data | R Documentation |
This dataset extends the macro-economic data from example_longterm_predictions until the year 2028. The macro-econmic data for the years 2023 until 2028 is derived from the World Economic Outlook Database (April 2023 edition) of the International Monetary Fund (IMF) (https://www.imf.org/en/Publications/WEO/weo-database/2023/October).
example_longterm_future_macro_data
A data frame with 23 rows and 18 columns:
countryThe country, represented by the ISO2C country code (e.g., FR for France).
yearThe year of the observation.
avg_hourly_demandThe average hourly electricity demand (in megawatts) for the respective year.
populationThe total population in the respective year.
GDPGross Domestic Product (in constant 2015 USD) in the respective year.
industrial_value_addedThe percentage of GDP attributed to industrial value-added activities.
manufacturing_value_addedThe percentage of GDP attributed to manufacturing value-added activities.
GDP_growthThe GDP growth rate (in percentage) for the respective year.
GDP_deflatorThe GDP deflator (in percentage), which measures price inflation or deflation.
service_value_addedThe percentage of GDP attributed to service sector value-added activities.
GNIGross National Income (in constant 2015 USD) in the respective year.
household_consumption_expenditureThe percentage of GDP attributed to household consumption expenditure.
rural_populationThe rural population in the respective year.
longterm_model_predictions1Predictions for the long-term trend component of electricity demand based on Model 1.
longterm_model_predictions2Predictions for the long-term trend component of electricity demand based on Model 2.
longterm_model_predictions3Predictions for the long-term trend component of electricity demand based on Model 3.
test_set_stepsThe number of years used in the test or validation set for the model evaluation.
exampleA boolean indicator to mark this dataset as an example dataset.
World Economic Outlook Database (April 2023 edition) of the International Monetary Fund (IMF) (https://www.imf.org/en/Publications/WEO/weo-database/2023/October); World Development Indicators (WDI) of the World Bank (https://databank.worldbank.org/source/world-development-indicators); Transparency Platform of the European Network of Transmission System Operators for Electricity (ENTSO-E, https://transparency.entsoe.eu/); ENTSO-E Power Stats Archive of https://www.entsoe.eu/data/power-stats/
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.