This dataset extends the example_midterm_demand_data by adding a weighted average temperature column.
The dataset is divided into two parts: demand and temperature_data. The demand dataframe contains the added
weighted average temperature column and the other demand related data. The temperature_data dataframe contains the daily temperature observations
for the 20 most populated regions. This data is provided to show from which locations the weather data was taken.
example_midterm_demand_and_weather_dataA list containing two data frames:
demandA data frame with 1,825 rows and 10 columns, representing mid-term electricity demand data.
temperature_dataA data frame with 1,826 rows and 22 columns, representing temperature measurements across multiple cities.
Demand Data Frame:
demand.countryThe country, represented by the ISO2C country code (e.g., FR for France).
demand.dateThe date of the demand measurement (in YYYY-MM-DD format).
demand.yearThe respective year.
demand.monthThe respective month.
demand.dayThe respective day.
demand.wdayThe type of weekday (e.g., Sun, Mon)
demand.avg_hourly_demandThe average hourly electricity demand (in megawatts) for each day.
demand.seasonal_avg_hourly_demandThe seasonal mid-term component of the demand (in megawatts).
demand.weighted_temperatureThe weighted average temperature for France on that day (in degrees Celsius).
exampleA boolean indicator to mark this dataset as an example dataset.
Temperature Data Frame:
dateThe date of the temperature observation (in YYYY-MM-DD format).
Paris, Marseille, Lyon, Toulouse, Nice, Nantes, Montpellier, Strasbourg, Bordeaux,Cergy-Pontoise,Toulon,Reims, Lille,15th arrondissement of Paris, 20th arrondissement of Paris, 18th arrondissement of Paris, 19th arrondissement of Paris, 13th arrondissement of ParisThe daily average temperature readings (in degrees Celsius) for various cities or city districts on that date.
weighted_mean_temperatureThe weighted (by share of population) mean temperature across the country for the respective date.