get_entsoE_data: Load data from the ENTSO-E Transparency Platform
Description
This function makes various API requests to the Transparency Platform of the European Network of
Transmission System Operators for Electricity (ENTSO-E, https://transparency.entsoe.eu/) and
stores the downloaded load data in a data frame. The earliest possible year for the requested load time series is 2017.